/*
  Copyright 2018 Tautvydas Andrikys

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

      http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.esminis.server.mariadb.server;

import android.content.Context;

import com.esminis.server.library.model.log.LogRecord;
import com.esminis.server.library.server.ServerControl;
import com.esminis.server.library.server.ServerControlDependencies;
import com.esminis.server.library.server.ServerControlStartConfig;

import java.io.IOException;

import javax.inject.Inject;
import javax.inject.Singleton;

@Singleton
public class MariaDb extends ServerControl<MariaDbServerLauncher> {

	@Inject
	public MariaDb(ServerControlDependencies dependencies) {
		super(dependencies, "mysqld", new MariaDbServerLauncher(dependencies.managerProcess));
	}

	@Override
	protected Process start(ServerControlStartConfig config) throws IOException {
		return launcher.start(config, context);
	}

	@Override
	protected void stop(java.lang.Process process) {
		launcher.stop(process, getBinary());
	}

	void initializeDataDirectory(Context context) throws IOException {
		launcher.initializeDataDirectory(context, getBinary(), preferences.getRootDirectory());
	}

	@Override
	protected void waitWhileStarting(Process process) throws ServerStartupException {
		super.waitWhileStarting(
			process, new DefaultServerStreamHandler(this, process, false) {

				@Override
				protected boolean isStarted(LogRecord record) throws ServerStartupException {
					if (record.type == LogRecord.TYPE_ERROR && record.content.contains("error")) {
						throw new ServerStartupException(record.content);
					}
					return record.content.startsWith("Version: ");
				}

			}
		);
	}
}
